@@ -27,12 +27,13 @@ struct ccase;
 
 /* Creating dictionaries. */
 struct dictionary *dict_create (const char *encoding);
-struct dictionary *dict_clone (const struct dictionary *);
+struct dictionary *dict_clone (const struct dictionary *) WARN_UNUSED_RESULT;
+struct dictionary *dict_ref (struct dictionary *s) WARN_UNUSED_RESULT;
 
 
 /* Clearing and destroying dictionaries. */
 void dict_clear (struct dictionary *);
-void dict_destroy (struct dictionary *);
+void dict_unref (struct dictionary *);
 
 /* Common ways to access variables. */
 struct variable *dict_lookup_var (const struct dictionary *, const char *);
@@ -91,6 +92,9 @@ bool dict_rename_vars (struct dictionary *,
 char *dict_make_unique_var_name (const struct dictionary *, const char *hint,
                                  unsigned long int *num_start);
 
+bool dict_get_names_must_be_ids (const struct dictionary *);
+void dict_set_names_must_be_ids (struct dictionary *, bool);
+
 /* Weight variable. */
 double dict_get_case_weight (const struct dictionary *,
 			     const struct ccase *, bool *);
