@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000, 2006, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2006, 2009, 2010, 2011, 2012, 2013, 2014, 2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,6 +42,42 @@
 
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
+#define N_(msgid) (msgid)
+
+/* This should follow the definition in Gtk */
+typedef struct
+{
+  int value;
+  const char *name;
+  const char *label;
+} GEnumValue;
+
+const GEnumValue align[] =
+  {
+    {ALIGN_LEFT,   "left", N_("Left")},
+    {ALIGN_RIGHT,  "right", N_("Right")},
+    {ALIGN_CENTRE, "center", N_("Center")},
+    {0,0,0}
+  };
+
+const GEnumValue measure[] =
+  {
+    {MEASURE_NOMINAL, "nominal", N_("Nominal")},
+    {MEASURE_ORDINAL, "ordinal", N_("Ordinal")},
+    {MEASURE_SCALE,   "scale", N_("Scale")},
+    {0,0,0}
+  };
+
+const GEnumValue role[] =
+  {
+    {ROLE_INPUT,  "input",    N_("Input")},
+    {ROLE_TARGET, "output",   N_("Output")},
+    {ROLE_BOTH,   "both",     N_("Both")},
+    {ROLE_NONE,   "none",     N_("None")},
+    {ROLE_PARTITION, "partition", N_("Partition")},
+    {ROLE_SPLIT,  "split",    N_("Split")},
+    {0,0,0}
+  };
 
 /* A variable. */
 struct variable
@@ -150,7 +186,6 @@ static void
 var_set_name_quiet (struct variable *v, const char *name)
 {
   assert (!var_has_vardict (v));
-  assert (id_is_plausible (name, false));
 
   free (v->name);
   v->name = xstrdup (name);
@@ -771,20 +806,8 @@ measure_is_valid (enum measure m)
 const char *
 measure_to_string (enum measure m)
 {
-  switch (m)
-    {
-    case MEASURE_NOMINAL:
-      return _("Nominal");
-
-    case MEASURE_ORDINAL:
-      return _("Ordinal");
-
-    case MEASURE_SCALE:
-      return _("Scale");
-
-    default:
-      return "Invalid";
-    }
+  assert (m == measure[m].value);
+  return gettext (measure[m].label);
 }
 
 /* Returns a string version of measurement level M, for use in PSPP command
@@ -866,31 +889,10 @@ var_role_is_valid (enum var_role role)
 
 /* Returns a string version of ROLE, for display to a user. */
 const char *
-var_role_to_string (enum var_role role)
+var_role_to_string (enum var_role r)
 {
-  switch (role)
-    {
-    case ROLE_INPUT:
-      return _("Input");
-
-    case ROLE_TARGET:
-      return _("Output");
-
-    case ROLE_BOTH:
-      return _("Both");
-
-    case ROLE_NONE:
-      return _("None");
-
-    case ROLE_PARTITION:
-      return _("Partition");
-
-    case ROLE_SPLIT:
-      return _("Split");
-
-    default:
-      return "Invalid";
-    }
+  assert (r == role[r].value);
+  return gettext (role[r].label);
 }
 
 /* Returns a string version of ROLE, for use in PSPP comamnd syntax. */
@@ -996,20 +998,8 @@ alignment_is_valid (enum alignment a)
 const char *
 alignment_to_string (enum alignment a)
 {
-  switch (a)
-    {
-    case ALIGN_LEFT:
-      return _("Left");
-
-    case ALIGN_RIGHT:
-      return _("Right");
-
-    case ALIGN_CENTRE:
-      return _("Center");
-
-    default:
-      return "Invalid";
-    }
+  assert (a == align[a].value);
+  return gettext (align[a].label);
 }
 
 /* Returns a string version of alignment A, for use in PSPP command syntax. */
@@ -1141,8 +1131,6 @@ var_set_short_name (struct variable *var, size_t idx, const char *short_name)
 {
   struct variable *ov = var_clone (var);
 
-  assert (short_name == NULL || id_is_plausible (short_name, false));
-
   /* Clear old short name numbered IDX, if any. */
   if (idx < var->short_name_cnt)
     {
