@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2010, 2011, 2012, 2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,21 +25,20 @@
 
 #include <stdbool.h>
 #include <stddef.h>
-#include <libpspp/legacy-encoding.h>
 
 struct file_handle;
 struct string;
 struct lexer;
 
 /* Input. */
-struct dfm_reader *dfm_open_reader (struct file_handle *, struct lexer *);
+struct dfm_reader *dfm_open_reader (struct file_handle *, struct lexer *,
+                                    const char *encoding);
 void dfm_close_reader (struct dfm_reader *);
 bool dfm_reader_error (const struct dfm_reader *);
 unsigned dfm_eof (struct dfm_reader *);
 struct substring dfm_get_record (struct dfm_reader *);
 void dfm_expand_tabs (struct dfm_reader *);
-const char *dfm_reader_get_legacy_encoding (const struct dfm_reader *);
-int dfm_get_percent_read (const struct dfm_reader *);
+const char *dfm_reader_get_encoding (const struct dfm_reader *);
 
 /* Line control. */
 void dfm_forward_record (struct dfm_reader *);
@@ -49,8 +48,8 @@ size_t dfm_column_start (const struct dfm_reader *);
 size_t dfm_columns_past_end (const struct dfm_reader *);
 size_t dfm_get_column (const struct dfm_reader *, const char *);
 
-/* File stack. */
-void dfm_push (struct dfm_reader *);
-void dfm_pop (struct dfm_reader *);
+/* Information. */
+const char *dfm_get_file_name (const struct dfm_reader *);
+int dfm_get_line_number (const struct dfm_reader *);
 
 #endif /* data-reader.h */
