@@ -26,7 +26,7 @@
 #include "libpspp/cast.h"
 #include "output/driver.h"
 #include "ui/gui/psppire-data-store.h"
-#include "ui/gui/psppire-output-window.h"
+#include "ui/gui/psppire.h"
 
 /* Lazy casereader callback function used by execute_syntax. */
 static struct casereader *
@@ -200,5 +200,5 @@ execute_syntax_string (PsppireDataWindow *window, gchar *syntax)
 void
 execute_const_syntax_string (PsppireDataWindow *window, const gchar *syntax)
 {
-  execute_syntax (window, lex_reader_for_string (syntax));
+  execute_syntax (window, lex_reader_for_string (syntax, "UTF-8"));
 }
