@@ -52,8 +52,6 @@ generate_syntax (const PsppireDialogAction *act)
   return text;
 }
 
-
-
 static gboolean
 dialog_state_valid (gpointer user_data)
 {
@@ -81,19 +79,13 @@ refresh (PsppireDialogAction *fd_)
   gtk_entry_set_text (GTK_ENTRY (fd->entry), "");
 }
 
-static void
-psppire_dialog_action_kmeans_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_kmeans_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogActionKmeans *act = PSPPIRE_DIALOG_ACTION_KMEANS (a);
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("k-means.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ( "k-means.ui");
 
   pda->dialog = get_widget_assert   (xml, "k-means-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
@@ -104,14 +96,13 @@ psppire_dialog_action_kmeans_activate (PsppireDialogAction *a)
   psppire_dialog_action_set_refresh (pda, refresh);
   psppire_dialog_action_set_valid_predicate (pda, dialog_state_valid);
 
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_kmeans_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_kmeans_parent_class)->activate (pda);
+  return xml;
 }
 
 static void
 psppire_dialog_action_kmeans_class_init (PsppireDialogActionKmeansClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_kmeans_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_kmeans_activate;
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
 
