@@ -79,14 +79,14 @@ on_opts_clicked (PsppireDialogActionLogistic *act)
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (act->cut_point_entry), act->cut_point);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (act->iterations_entry), act->max_iterations);
 
-  
+
   ret = psppire_dialog_run (PSPPIRE_DIALOG (act->opts_dialog));
 
   if ( ret == PSPPIRE_RESPONSE_CONTINUE )
     {
       act->conf = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(act->conf_checkbox));
       act->conf_level = gtk_spin_button_get_value (GTK_SPIN_BUTTON (act->conf_entry));
-      
+
       act->constant = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(act->const_checkbox));
 
       act->cut_point = gtk_spin_button_get_value (GTK_SPIN_BUTTON (act->cut_point_entry));
@@ -95,20 +95,14 @@ on_opts_clicked (PsppireDialogActionLogistic *act)
 }
 
 
-static void
-psppire_dialog_action_logistic_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_logistic_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogActionLogistic *act = PSPPIRE_DIALOG_ACTION_LOGISTIC (a);
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
   GtkWidget *opts_button;
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("logistic.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ( "logistic.ui");
 
   pda->dialog = get_widget_assert   (xml, "logistic-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
@@ -134,7 +128,7 @@ psppire_dialog_action_logistic_activate (PsppireDialogAction *a)
 			    G_CALLBACK (on_opts_clicked),  act);
 
   g_signal_connect (act->conf_checkbox, "toggled",
-		    G_CALLBACK (set_sensitivity_from_toggle),  
+		    G_CALLBACK (set_sensitivity_from_toggle),
 		    act->conf_entry);
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(act->conf_checkbox), TRUE);
@@ -145,8 +139,7 @@ psppire_dialog_action_logistic_activate (PsppireDialogAction *a)
   psppire_dialog_action_set_valid_predicate (pda,
 					dialog_state_valid);
 
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_logistic_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_logistic_parent_class)->activate (pda);
+  return xml;
 }
 
 
@@ -211,7 +204,7 @@ generate_syntax (const PsppireDialogAction *a)
       g_string_append_printf (strx, "\n\t/PRINT = CI(%g)", rd->conf_level);
     }
 
-  if (rd->constant) 
+  if (rd->constant)
     g_string_append (strx, "\n\t/NOORIGIN");
   else
     g_string_append (strx, "\n\t/ORIGIN");
@@ -228,7 +221,7 @@ generate_syntax (const PsppireDialogAction *a)
 static void
 psppire_dialog_action_logistic_class_init (PsppireDialogActionLogisticClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_logistic_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_logistic_activate;
 
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
