@@ -90,7 +90,7 @@ struct _PsppireDialogActionRecode
   GtkWidget *change_button;
 
   GtkWidget *output_variable_box;
-  
+
   GtkWidget *string_button;
   GtkWidget *width_entry;
 };
@@ -107,7 +107,8 @@ GType psppire_dialog_action_recode_get_type (void) ;
 
 void psppire_dialog_action_recode_refresh (PsppireDialogAction *);
 
-void psppire_dialog_action_recode_pre_activate (PsppireDialogActionRecode *act, void (*populate_treeview) (PsppireDialogActionRecode *) );
+GtkBuilder * psppire_dialog_action_recode_pre_activate (PsppireDialogActionRecode *act,
+							void (*populate_treeview) (PsppireDialogActionRecode *) );
 
 
 GType new_value_get_type (void);
