@@ -62,10 +62,10 @@ dialog_state_valid (gpointer data)
   value_init (&val, width);
 
   result = psppire_value_entry_get_value (PSPPIRE_VALUE_ENTRY (rd->state_value), &val, width);
-  
+
   if (var_is_value_missing (var, &val, MV_SYSTEM))
       result = FALSE;
-  
+
   value_destroy (&val, width);
 
   return result;
@@ -80,7 +80,7 @@ on_curve_button_toggle (GtkCheckButton *curve, PsppireDialogActionRoc *rd)
 	g_object_set (rd->reference, "inconsistent", TRUE, NULL);
       g_object_set (rd->reference, "sensitive", FALSE, NULL);
     }
-  else 
+  else
     {
       g_object_set (rd->reference, "inconsistent", FALSE, NULL);
       g_object_set (rd->reference, "sensitive", TRUE, NULL);
@@ -120,20 +120,13 @@ on_state_var_changed (PsppireDialogAction *a)
   psppire_value_entry_set_variable (PSPPIRE_VALUE_ENTRY (act->state_value), var);
 }
 
-static void
-psppire_dialog_action_roc_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_roc_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogActionRoc *act = PSPPIRE_DIALOG_ACTION_ROC (a);
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("roc.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
-
+  GtkBuilder *xml = builder_new ( "roc.ui");
 
   pda->dialog = get_widget_assert   (xml, "roc-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
@@ -157,9 +150,7 @@ psppire_dialog_action_roc_activate (PsppireDialogAction *a)
 
   psppire_dialog_action_set_valid_predicate (pda,
 					dialog_state_valid);
-
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_roc_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_roc_parent_class)->activate (pda);
+  return xml;
 }
 
 
@@ -194,10 +185,10 @@ generate_syntax (const PsppireDialogAction *a)
     {
       struct string str;
       ds_init_empty (&str);
-      
+
       syntax_gen_value (&str, &val, var_get_width (var),
 			var_get_print_format (var));
-      
+
       g_string_append (string, ds_cstr (&str));
       ds_destroy (&str);
     }
@@ -244,7 +235,7 @@ generate_syntax (const PsppireDialogAction *a)
 static void
 psppire_dialog_action_roc_class_init (PsppireDialogActionRocClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_roc_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_roc_activate;
 
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
