@@ -38,7 +38,7 @@ generate_syntax (const PsppireDialogAction *act)
   GString *str = g_string_new ("GLM ");
 
   g_string_append (str, gtk_entry_get_text (GTK_ENTRY (uvd->dep_entry)));
-  
+
   g_string_append (str, " BY ");
 
   psppire_var_view_append_names (PSPPIRE_VAR_VIEW (uvd->factor_list), 0, str);
@@ -82,19 +82,13 @@ refresh (PsppireDialogAction *rd_)
   gtk_list_store_clear (GTK_LIST_STORE (liststore));
 }
 
-static void
-psppire_dialog_action_univariate_activate (PsppireDialogAction *a)
+static GtkBuilder *
+psppire_dialog_action_univariate_activate (PsppireDialogAction *a, GVariant *param)
 {
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
   PsppireDialogActionUnivariate *act = PSPPIRE_DIALOG_ACTION_UNIVARIATE (a);
 
-  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
-  GtkBuilder *xml = g_hash_table_lookup (thing, a);
-  if (!xml)
-    {
-      xml = builder_new ("univariate.ui");
-      g_hash_table_insert (thing, a, xml);
-    }
+  GtkBuilder *xml = builder_new ( "univariate.ui");
 
   pda->dialog = get_widget_assert   (xml, "univariate-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
@@ -104,15 +98,13 @@ psppire_dialog_action_univariate_activate (PsppireDialogAction *a)
 
   psppire_dialog_action_set_valid_predicate (pda, dialog_state_valid);
   psppire_dialog_action_set_refresh (pda, refresh);
-
-  if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_univariate_parent_class)->activate)
-    PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_univariate_parent_class)->activate (pda);
+  return xml;
 }
 
 static void
 psppire_dialog_action_univariate_class_init (PsppireDialogActionUnivariateClass *class)
 {
-  psppire_dialog_action_set_activation (class, psppire_dialog_action_univariate_activate);
+  PSPPIRE_DIALOG_ACTION_CLASS (class)->initial_activate = psppire_dialog_action_univariate_activate;
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
 
